<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="30"/>
        <source>Print playback status</source>
        <translation>Afficher le statut de lecture</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="31"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Afficher le nom de piste formaté (par exemple : qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="33"/>
        <source>Print --nowplaying syntax</source>
        <translation>Afficher la syntaxe de --nowplaying</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>Syntax:</source>
        <translation>Syntaxe :</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%p - artist</source>
        <translation>%p - artiste</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%a - album</source>
        <translation>%a - album</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%aa - album artist</source>
        <translation>%aa - artiste d&apos;album</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%t - title</source>
        <translation>%t - titre</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%n - track</source>
        <translation>%n - numéro de piste</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - numéro de piste à 2 chiffres</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%g - genre</source>
        <translation>%g - genre</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%c - comment</source>
        <translation>%c - commentaire</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%C - composer</source>
        <translation>%C - compositeur</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%D - disc number</source>
        <translation>%D - numéro de disque</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="105"/>
        <source>%f - file name</source>
        <translation>%f - nom du fichier</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="106"/>
        <source>%F - full path</source>
        <translation>%F - chemin du fichier</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="107"/>
        <source>%y - year</source>
        <translation>%y - année</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="108"/>
        <source>%l - duration</source>
        <translation>%l - durée</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="109"/>
        <source>%{bitrate} - bitrate</source>
        <translation>%{débit} - débit</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="110"/>
        <source>%{samplerate} - sample rate</source>
        <translation>%{samplerate} - taux d&apos;échantillonnage</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="111"/>
        <source>%{channels} - number of channels</source>
        <translation>%{channels} - nombre de canaux</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="112"/>
        <source>%{samplesize} - bits per sample</source>
        <translation>%{samplesize} - taille déchantillonnage</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="113"/>
        <source>%{format} - format name</source>
        <translation>%{format} - formatage du nom</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="114"/>
        <source>%{decoder} - decoder name</source>
        <translation>%{decoder} - nom du décodeur</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="115"/>
        <source>%{filesize} - file size</source>
        <translation>%{filesize} - taille du fichier</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="116"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - condition</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="117"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - nom du répertoire situé à n niveaux au dessus</translation>
    </message>
</context>
</TS>
